@@ -81,6 +81,7 @@ from .delish import Delish
 from .dinneratthezoo import DinnerAtTheZoo
 from .dinnerthendessert import DinnerThenDessert
 from .dishnz import Dishnz
+from .dobruchutaktualitysk import DobruChutAktualitySK
 from .domesticateme import DomesticateMe
 from .downshiftology import Downshiftology
 from .dr import Dr
@@ -138,7 +139,7 @@ from .headbangerskitchen import HeadbangersKitchen
 from .heatherchristo import HeatherChristo
 from .heb import HEB
 from .hellofresh import HelloFresh
-from .herseyland import HerseyLand
+from .hersheyland import HersheyLand
 from .homechef import HomeChef
 from .hostthetoast import Hostthetoast
 from .ica import Ica
@@ -182,6 +183,7 @@ from .lekkerensimpel import LekkerEnSimpel
 from .leukerecepten import Leukerecepten
 from .lifestyleofafoodie import LifestyleOfAFoodie
 from .littlespicejar import LittleSpiceJar
+from .littlesunnykitchen import LittleSunnyKitchen
 from .livelytable import LivelyTable
 from .lovingitvegan import Lovingitvegan
 from .maangchi import Maangchi
@@ -218,6 +220,7 @@ from .nhshealthierfamilies import NHSHealthierFamilies
 from .nibbledish import NibbleDish
 from .nihhealthyeating import NIHHealthyEating
 from .norecipes import NoRecipes
+from .nosalty import NoSalty
 from .notenoughcinnamon import NotEnoughCinnamon
 from .nourishedbynutrition import NourishedByNutrition
 from .nrkmat import NRKMat
@@ -256,6 +259,7 @@ from .realfoodtesco import RealFoodTesco
 from .realsimple import RealSimple
 from .receitasnestlebr import ReceitasNestleBR
 from .recept import Recept
+from .receptyprevas import ReceptyPreVas
 from .recipegirl import RecipeGirl
 from .reciperunner import RecipeRunner
 from .recipetineats import RecipeTinEats
@@ -266,7 +270,7 @@ from .ricetta import Ricetta
 from .ricetteperbimby import RicettePerBimby
 from .rosannapansino import RosannaPansino
 from .rutgerbakt import RutgerBakt
-from .saboresanjinomoto import SaboresAnjinomoto
+from .saboresajinomoto import SaboresAjinomoto
 from .sallysbakingaddiction import SallysBakingAddiction
 from .sallysblog import SallysBlog
 from .saltpepperskillet import SaltPepperSkillet
@@ -331,6 +335,7 @@ from .usapears import USAPears
 from .usdamyplate import USDAMyPlate
 from .valdemarsro import Valdemarsro
 from .vanillaandbean import VanillaAndBean
+from .varechapravdask import VarechaPravdaSK
 from .vegetarbloggen import Vegetarbloggen
 from .vegolosi import Vegolosi
 from .vegrecipesofindia import VegRecipesOfIndia
@@ -382,6 +387,7 @@ SCRAPERS = {
     BBCFood.host(domain="co.uk"): BBCFood,
     BBCGoodFood.host(): BBCGoodFood,
     Bakels.host(): Bakels,
+    Bakels.host(domain="co.uk"): Bakels,
     BakingSense.host(): BakingSense,
     BakingMischief.host(): BakingMischief,
     BareFootContessa.host(): BareFootContessa,
@@ -429,6 +435,7 @@ SCRAPERS = {
     DinnerAtTheZoo.host(): DinnerAtTheZoo,
     DinnerThenDessert.host(): DinnerThenDessert,
     Dishnz.host(): Dishnz,
+    DobruChutAktualitySK.host(): DobruChutAktualitySK,
     EatLiveRun.host(): EatLiveRun,
     ElaVegan.host(): ElaVegan,
     EvolvingTable.host(): EvolvingTable,
@@ -445,6 +452,7 @@ SCRAPERS = {
     KitchenAidAustralia.host(): KitchenAidAustralia,
     KristinesKitchenBlog.host(): KristinesKitchenBlog,
     KuchynaLidla.host(): KuchynaLidla,
+    LittleSunnyKitchen.host(): LittleSunnyKitchen,
     McCormick.host(): McCormick,
     ModernHoney.host(): ModernHoney,
     MomOnTimeout.host(): MomOnTimeout,
@@ -458,6 +466,7 @@ SCRAPERS = {
     PinchOfYum.host(): PinchOfYum,
     PotatoRolls.host(): PotatoRolls,
     Recept.host(): Recept,
+    ReceptyPreVas.host(): ReceptyPreVas,
     RecipeGirl.host(): RecipeGirl,
     RicettePerBimby.host(): RicettePerBimby,
     SavoryNothings.host(): SavoryNothings,
@@ -534,7 +543,7 @@ SCRAPERS = {
     HelloFresh.host(domain="nl"): HelloFresh,
     HelloFresh.host(domain="no"): HelloFresh,
     HelloFresh.host(domain="se"): HelloFresh,
-    HerseyLand.host(): HerseyLand,
+    HersheyLand.host(): HersheyLand,
     HomeChef.host(): HomeChef,
     Hostthetoast.host(): Hostthetoast,
     Ica.host(): Ica,
@@ -609,6 +618,7 @@ SCRAPERS = {
     NIHHealthyEating.host(): NIHHealthyEating,
     NYTimes.host(): NYTimes,
     NoRecipes.host(): NoRecipes,
+    NoSalty.host(): NoSalty,
     NourishedByNutrition.host(): NourishedByNutrition,
     Number2Pencil.host(): Number2Pencil,
     NutritionByNathalie.host(): NutritionByNathalie,
@@ -648,7 +658,7 @@ SCRAPERS = {
     Ricetta.host(): Ricetta,
     RosannaPansino.host(): RosannaPansino,
     RutgerBakt.host(): RutgerBakt,
-    SaboresAnjinomoto.host(): SaboresAnjinomoto,
+    SaboresAjinomoto.host(): SaboresAjinomoto,
     SallysBakingAddiction.host(): SallysBakingAddiction,
     SallysBlog.host(): SallysBlog,
     SaltPepperSkillet.host(): SaltPepperSkillet,
@@ -704,6 +714,7 @@ SCRAPERS = {
     Unsophisticook.host(): Unsophisticook,
     Valdemarsro.host(): Valdemarsro,
     VanillaAndBean.host(): VanillaAndBean,
+    VarechaPravdaSK.host(): VarechaPravdaSK,
     VegRecipesOfIndia.host(): VegRecipesOfIndia,
     Vegetarbloggen.host(): Vegetarbloggen,
     Vegolosi.host(): Vegolosi,
@@ -741,21 +752,33 @@ def scraper_exists_for(url_path: str) -> bool:
     return host_name in get_supported_urls()
 
 
+def _emit_scrape_me_deprecation_notice():
+    msg = (
+        "The 'recipe_scrapers.scrape_me' function is deprecated, and support for "
+        "it will be dropped in future.  When possible, please begin using the "
+        "preferred 'recipe_scrapers.scrape_html' function instead.\n"
+    )
+    warnings.warn(msg, DeprecationWarning)
+
+
+def _emit_options_deprecation_notice():
+    msg = (
+        "Scraper options arguments (e.g. proxies=, timeout=) are deprecated, and "
+        "support for them will be dropped in future.  To migrate, please:\n"
+        "\n"
+        " * Use an HTTP client (such as 'requests' or 'httpx') configured with "
+        "the proxies/timeout settings you want.\n"
+        " * Retrieve recipe HTML using the appropriately-configured HTTP client.\n"
+        " * Scrape retrieved recipe HTML using the 'recipe_scrapers.scrape_html' "
+        "function.\n"
+    )
+    warnings.warn(msg, DeprecationWarning)
+
+
 def scrape_me(url_path: str, **options: Any) -> AbstractScraper:
     host_name = get_host_name(url_path)
 
-    if options:
-        msg = (
-            "Scraper options arguments (e.g. proxies=, timeout=) are deprecated, and "
-            "support for them will be dropped in future.  To migrate, please:\n"
-            "\n"
-            " * Use an HTTP client (such as 'requests' or 'httpx') configured with "
-            "the proxies/timeout settings you want.\n"
-            " * Retrieve recipe HTML using the appropriately-configured HTTP client.\n"
-            " * Scrape retrieved recipe HTML using the 'recipe_scrapers.scrape_html' "
-            "function.\n"
-        )
-        warnings.warn(msg, DeprecationWarning)
+    _emit_scrape_me_deprecation_notice()
 
     try:
         scraper = SCRAPERS[host_name]
@@ -764,11 +787,15 @@ def scrape_me(url_path: str, **options: Any) -> AbstractScraper:
             raise WebsiteNotImplementedError(host_name)
         else:
             options.pop("wild_mode")
+            if options:
+                _emit_options_deprecation_notice()
             wild_scraper = SchemaScraperFactory.generate(url_path, **options)
             if not wild_scraper.schema.data:
                 raise NoSchemaFoundInWildMode(url_path)
             return wild_scraper
 
+    if options:
+        _emit_options_deprecation_notice()
     return scraper(url_path, **options)
 
 
@@ -794,23 +821,18 @@ def scrape_html(
 
     host_name = get_host_name(org_url) if org_url is not None else None
 
-    if options:
-        msg = (
-            "Scraper options arguments (e.g. proxies=, timeout=) are deprecated, and "
-            "support for them will be dropped in future.  To migrate, please:\n"
-            "\n"
-            " * Use an HTTP client (such as 'requests' or 'httpx') configured with "
-            "the proxies/timeout settings you want.\n"
-            " * Retrieve recipe HTML using the appropriately-configured HTTP client.\n"
-        )
-        warnings.warn(msg, DeprecationWarning)
-
     scraper = None
     if host_name:
         with contextlib.suppress(KeyError):
             scraper = SCRAPERS[host_name]
 
     if not scraper:
+        if not options.get("wild_mode", False):
+            raise WebsiteNotImplementedError(host_name)
+
+        options.pop("wild_mode")
+        if options:
+            _emit_options_deprecation_notice()
         wild_scraper = SchemaScraperFactory.generate(url=org_url, html=html, **options)
 
         if not wild_scraper.schema.data:
@@ -818,6 +840,8 @@ def scrape_html(
 
         return wild_scraper
 
+    if options:
+        _emit_options_deprecation_notice()
     return scraper(url=org_url, html=html, **options)
 
 
