@@ -1,4 +1,3 @@
-# mypy: disallow_untyped_defs=False
 import inspect
 from collections import OrderedDict
 from typing import Dict, List, Optional, Tuple, Union
@@ -9,7 +8,9 @@ from bs4 import BeautifulSoup
 
 from recipe_scrapers.settings import settings
 
+from ._exceptions import ElementNotFoundInHtml
 from ._grouping_utils import IngredientGroup
+from ._opengraph import OpenGraph
 from ._schemaorg import SchemaOrg
 
 # Some sites close their content for 'bots', so user-agent must be supplied
@@ -49,6 +50,7 @@ class AbstractScraper:
 
         self.wild_mode = wild_mode
         self.soup = BeautifulSoup(self.page_data, "html.parser")
+        self.opengraph = OpenGraph(self.soup)
         self.schema = SchemaOrg(self.page_data)
 
         # attach the plugins as instructed in settings.PLUGINS
@@ -61,9 +63,8 @@ class AbstractScraper:
                 setattr(self.__class__, name, current_method)
             setattr(self.__class__, "plugins_initialized", True)
 
-    @classmethod
-    def host(cls) -> str:
-        """Host domain of the recipe URL."""
+    def author(self):
+        """Author of the recipe."""
         raise NotImplementedError("This should be implemented.")
 
     def canonical_url(self):
@@ -73,51 +74,21 @@ class AbstractScraper:
             return urljoin(self.url, canonical_link["href"])
         return self.url
 
-    def title(self):
-        """Title of the recipe."""
+    def site_name(self):
+        """Name of the website."""
         raise NotImplementedError("This should be implemented.")
 
-    def category(self):
-        """Category of the recipe."""
-        raise NotImplementedError("This should be implemented.")
-
-    def total_time(self):
-        """Total time needed to prepare and cook the recipe in minutes."""
-        raise NotImplementedError("This should be implemented.")
-
-    def cook_time(self):
-        """Cooking time in minutes."""
-        raise NotImplementedError("This should be implemented.")
-
-    def prep_time(self):
-        """Preparation time in minutes."""
-        raise NotImplementedError("This should be implemented.")
-
-    def cooking_method(self):
-        """The method of cooking the recipe"""
-        raise NotImplementedError("This should be implemented.")
-
-    def yields(self):
-        """Total servings or items in the recipe."""
-        raise NotImplementedError("This should be implemented.")
-
-    def image(self):
-        """An image URL for the recipe."""
-        raise NotImplementedError("This should be implemented.")
-
-    def nutrients(self):
-        """Nutrients of the recipe."""
-        raise NotImplementedError("This should be implemented.")
-
-    def keywords(self):
-        """Keywords or tags used to describe the recipe"""
+    @classmethod
+    def host(cls) -> str:
+        """Host domain of the recipe URL."""
         raise NotImplementedError("This should be implemented.")
 
     def language(self):
         """Language the recipe is written in."""
         candidate_languages = OrderedDict()
         html = self.soup.find("html", {"lang": True})
-        candidate_languages[html.get("lang")] = True
+        if html:
+            candidate_languages[html.get("lang")] = True
 
         # Deprecated: check for a meta http-equiv header
         # See: https://www.w3.org/International/questions/qa-http-and-lang
@@ -138,7 +109,14 @@ class AbstractScraper:
             candidate_languages.pop("en", None)
 
         # Return the first candidate language
-        return candidate_languages.popitem(last=False)[0]
+        if candidate_languages:
+            return candidate_languages.popitem(last=False)[0]
+        else:
+            raise ElementNotFoundInHtml("Could not find language.")
+
+    def title(self):
+        """Title of the recipe."""
+        raise NotImplementedError("This should be implemented.")
 
     def ingredients(self):
         """Ingredients of the recipe."""
@@ -160,6 +138,38 @@ class AbstractScraper:
             if instruction
         ]
 
+    def category(self):
+        """Category of the recipe."""
+        raise NotImplementedError("This should be implemented.")
+
+    def yields(self):
+        """Total servings or items in the recipe."""
+        raise NotImplementedError("This should be implemented.")
+
+    def description(self):
+        """Description of the recipe."""
+        raise NotImplementedError("This should be implemented.")
+
+    def total_time(self):
+        """Total time needed to prepare and cook the recipe in minutes."""
+        raise NotImplementedError("This should be implemented.")
+
+    def cook_time(self):
+        """Cooking time in minutes."""
+        raise NotImplementedError("This should be implemented.")
+
+    def prep_time(self):
+        """Preparation time in minutes."""
+        raise NotImplementedError("This should be implemented.")
+
+    def cuisine(self):
+        """Cuisine of the recipe."""
+        raise NotImplementedError("This should be implemented.")
+
+    def cooking_method(self):
+        """The method of cooking the recipe"""
+        raise NotImplementedError("This should be implemented.")
+
     def ratings(self):
         """Ratings of the recipe."""
         raise NotImplementedError("This should be implemented.")
@@ -168,30 +178,30 @@ class AbstractScraper:
         """Total number of ratings of the recipe."""
         raise NotImplementedError("This should be implemented.")
 
-    def author(self):
-        """Author of the recipe."""
-        raise NotImplementedError("This should be implemented.")
-
-    def cuisine(self):
-        """Cuisine of the recipe."""
-        raise NotImplementedError("This should be implemented.")
-
-    def description(self):
-        """Description of the recipe."""
+    def equipment(self):
+        """Equipment needed for the recipe."""
         raise NotImplementedError("This should be implemented.")
 
     def reviews(self):
         """Reviews of the recipe."""
         raise NotImplementedError("This should be implemented.")
 
-    def equipment(self):
-        """Equipment needed for the recipe."""
+    def nutrients(self):
+        """Nutrients of the recipe."""
         raise NotImplementedError("This should be implemented.")
 
     def dietary_restrictions(self):
         """The specified dietary restrictions or guidelines for which this recipe is suitable"""
         raise NotImplementedError("This should be implemented.")
 
+    def image(self):
+        """An image URL for the recipe."""
+        raise NotImplementedError("This should be implemented.")
+
+    def keywords(self):
+        """Keywords or tags used to describe the recipe"""
+        raise NotImplementedError("This should be implemented.")
+
     def links(self):
         """Links found in the recipe."""
         invalid_href = {"#", ""}
@@ -199,11 +209,6 @@ class AbstractScraper:
 
         return [link.attrs for link in links_html if link["href"] not in invalid_href]
 
-    def site_name(self):
-        """Name of the website."""
-        meta = self.soup.find("meta", property="og:site_name")
-        return meta.get("content") if meta else None
-
     def to_json(self):
         """Recipe information in JSON format."""
         json_dict = {}
