@@ -1,4 +1,3 @@
-# mypy: disallow_untyped_defs=False
 # IF things in this file continue get messy (I'd say 300+ lines) it may be time to
 # find a package that parses https://schema.org/Recipe properly (or create one ourselves).
 from __future__ import annotations
@@ -37,17 +36,12 @@ class SchemaOrg:
             if self._contains_schematype(graph_item, schematype):
                 return graph_item
 
-    def __init__(self, page_data, raw=False):
-        if raw:
-            self.format = "raw"
-            self.data = page_data
-            self.people = {}
-            self.ratingsdata = {}
-            return
+    def __init__(self, page_data):
         self.format = None
         self.data = {}
         self.people = {}
         self.ratingsdata = {}
+        self.website_name = None
 
         data = extruct.extract(
             page_data,
@@ -56,6 +50,14 @@ class SchemaOrg:
             uniform=True,
         )
 
+        # Extract website data
+        for syntax in SYNTAXES:
+            syntax_data = data.get(syntax, [])
+            for item in syntax_data:
+                website = self._find_entity(item, "WebSite")
+                if website:
+                    self.website_name = website.get("name")
+
         # Extract person references
         for syntax in SYNTAXES:
             syntax_data = data.get(syntax, [])
@@ -102,6 +104,12 @@ class SchemaOrg:
                         self.data = main_entity
                         return
 
+    def site_name(self):
+        if not self.website_name:
+            raise SchemaOrgException("Site name not found in SchemaOrg")
+
+        return normalize_string(self.website_name)
+
     def language(self):
         return self.data.get("inLanguage") or self.data.get("language")
 
@@ -302,7 +310,7 @@ class SchemaOrg:
                 ratings = self.ratingsdata.get(rating_id, ratings)
             ratings = ratings.get("ratingCount") or ratings.get("reviewCount")
         if ratings:
-            return round(float(ratings), 2) if float(ratings) != 0 else None
+            return int(float(ratings)) if float(ratings) != 0 else None
         raise SchemaOrgException("No ratingCount in SchemaOrg.")
 
     def cuisine(self):
