@@ -1,5 +1,5 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import get_yields
 
 
@@ -8,6 +8,9 @@ class AfghanKitchenRecipes(AbstractScraper):
     def host(cls):
         return "afghankitchenrecipes.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Afghan Kitchen Recipes")
+
     def author(self):
         given_name = self.soup.find("h5", {"class": "given-name"})
         return given_name and given_name.find("a", {"rel": "author"}).get_text()
