@@ -1,7 +1,7 @@
-# mypy: disallow_untyped_defs=False
 import re
 
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import normalize_string
 
 
@@ -10,6 +10,9 @@ class AlbertHeijn(AbstractScraper):
     def host(cls):
         return "ah.nl"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Albert Heijn")
+
     def instructions(self):
         instructions = [
             normalize_string(step.get_text())
