@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 
 
 class BestRecipes(AbstractScraper):
@@ -9,4 +8,4 @@ class BestRecipes(AbstractScraper):
         return "bestrecipes.com.au"
 
     def language(self):
-        return "en-AU"
+        raise StaticValueException(return_value="en-AU")
