@@ -1,4 +1,5 @@
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import normalize_string
 
 
@@ -7,6 +8,9 @@ class BongEats(AbstractScraper):
     def host(cls):
         return "bongeats.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Bong Eats")
+
     def ingredients(self):
         ingredients_div = self.soup.find(
             "div",
