@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import normalize_string
 
 
@@ -9,6 +8,9 @@ class GesundAktiv(AbstractScraper):
     def host(cls):
         return "gesund-aktiv.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="gesund + aktiv")
+
     def title(self):
         return self.soup.find("h1", {"class": "page-header"}).get_text()
 
