@@ -1,7 +1,7 @@
-# mypy: disallow_untyped_defs=False
 import json
 
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._grouping_utils import IngredientGroup
 
 
@@ -17,6 +17,9 @@ class Mob(AbstractScraper):
     def host(cls):
         return "mob.co.uk"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Mob")
+
     def author(self):
         chefs = self.recipe_json.get("chefs", [])
         return " & ".join([chef["title"] for chef in chefs]) if chefs else "Mob Team"
