@@ -1,4 +1,3 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
 
 
@@ -7,5 +6,10 @@ class PurpleCarrot(AbstractScraper):
     def host(cls):
         return "purplecarrot.com"
 
+    def site_name(self):
+        home_link = self.soup.find("a", {"href": "/", "title": True})
+        if home_link:
+            return home_link["title"]
+
     def nutrients(self):
         return self.schema.nutrients()
