@@ -1,5 +1,5 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import normalize_string
 
 
@@ -8,6 +8,9 @@ class TimesOfIndia(AbstractScraper):
     def host(cls):
         return "recipes.timesofindia.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Times of India - Recipes")
+
     def ingredients(self):
         ingredients = self.soup.find_all("label", attrs={"class": "clearfix"})
 
